@@ -260,7 +260,7 @@ if(identical(Sys.getenv("NOT_CRAN"), "true")& .Machine$sizeof.pointer != 4){
   test_that("randomEffectsDRIFT", {
     set.seed(1)
     nsubjects <- 400
-    ntimes <- 20
+    ntimes <- 50
     
     baseline <- rnorm(nsubjects,2, 2)
     t0m <- rnorm(nsubjects,baseline/2,1)
@@ -304,7 +304,7 @@ if(identical(Sys.getenv("NOT_CRAN"), "true")& .Machine$sizeof.pointer != 4){
     f <- ctStanFit(datalong = dat,ctstanmodel = m,cores=cores,optimcontrol = list(stochastic=F,carefulfit=F))
     s=summary(f)
     s
-    subjpars=ctStanSubjectPars(f)[1,,] #calculate subject specific parameter estimates
+    subjpars=ctStanSubjectPars(f)[1,,c('T0m_eta1','drift','cint')] #calculate subject specific parameter estimates
     
     f2 <- ctStanFit(datalong = dat,ctstanmodel = m2,cores=cores,derrind=1,optimcontrol = list(stochastic=F,carefulfit=F))
     s2=summary(f2)
@@ -316,14 +316,14 @@ if(identical(Sys.getenv("NOT_CRAN"), "true")& .Machine$sizeof.pointer != 4){
     # checks ------------------------------------------------------------------
     mean(effect)
     
-    plot(subjpars[,1],baseline)
+    plot(subjpars[,'cint'],baseline)
     abline(0,1)
-    plot(subjpars[,2],effect)
+    plot(subjpars[,'drift'],effect)
     abline(0,1)
-    plot(subjpars[,3],t0m)
+    plot(subjpars[,'T0m_eta1'],t0m)
     abline(0,1)
     
-    plot(subjpars[,c(1,2)])
+    plot(subjpars[,c('cint','drift')])
     
     f$stanfit$transformedparsfull$popsd
     log1p_exp(2*f$stanfit$transformedparsfull$rawpopsdbase-1)
@@ -332,10 +332,10 @@ if(identical(Sys.getenv("NOT_CRAN"), "true")& .Machine$sizeof.pointer != 4){
     testthat::expect_equivalent(s$loglik,s2$loglik,tol=1e-2)
     
     #sd checks (f2 differences expected)
-    dfsd=data.frame(trueSample=c(sd(baseline),sd(t0m),sd(effect)),  #sample sd
-      subjPars=sqrt(diag(cov(subjpars)))[c(1,3,2)], #sd of individual effect point estimates
-      f2est=sqrt(diag(f2$stanfit$transformedparsfull$pop_T0cov[1,,]))[c(3,1,2)],
-      s$popsd[c('cint','T0m_eta1','drift'),]) #population estimate
+    dfsd=data.frame(trueSample=c(sd(t0m),sd(effect),sd(baseline)),  #sample sd
+      subjPars=sqrt(diag(cov(subjpars))), #sd of individual effect point estimates
+      f2est=sqrt(diag(f2$stanfit$transformedparsfull$pop_T0cov[1,,])),
+      s$popsd[c('T0m_eta1','drift','cint'),]) #population estimate
     
     #test sd of ctsem between subjects setup vs manual specification
     testthat::expect_equivalent(sqrt(diag(f2$stanfit$transformedparsfull$pop_T0cov[1,,])),
@@ -359,7 +359,7 @@ if(identical(Sys.getenv("NOT_CRAN"), "true")& .Machine$sizeof.pointer != 4){
     #corr checks
     dfcorr <-
       data.frame(trueSample=cor(cbind(t0m,raweffect,baseline))[lower.tri(diag(3))], #true (raw) sample cor,
-      subjPars=cor(subjpars[,c(3,1,2)])[lower.tri(diag(3))],
+      subjPars=cor(subjpars)[lower.tri(diag(3))],
       f1popCovbased=cov2cor(f$stanfit$transformedparsfull$popcov[1,,])[lower.tri(diag(3))],
       f2est=cov2cor(f2$stanfit$transformedparsfull$pop_T0cov[1,,])[lower.tri(diag(3))],
       s$rawpopcorr  )
@@ -428,10 +428,10 @@ if(identical(Sys.getenv("NOT_CRAN"), "true")& .Machine$sizeof.pointer != 4){
     m2$pars$indvarying=F
     
     f <- ctStanFit(datalong = dat,ctstanmodel = m,cores=cores,
-      optimcontrol = list(stochastic=F,carefulfit=F,bootstrapUncertainty=TRUE))#,init=f$stanfit$rawest)
+      optimcontrol = list(stochastic=F,carefulfit=F))#,init=f$stanfit$rawest)
     s=summary(f)
     s
-    subjpars=ctStanSubjectPars(f)[1,,] #calculate subject specific parameter estimates
+    subjpars=ctStanSubjectPars(f)[1,,c('t0m','diffusion','cint')] #calculate subject specific parameter estimates
     
     f2 <- ctStanFit(datalong = dat,ctstanmodel = m2,cores=cores,derrind=1,optimcontrol = list(stochastic=F,carefulfit=F))
     s2=summary(f2)
@@ -443,14 +443,14 @@ if(identical(Sys.getenv("NOT_CRAN"), "true")& .Machine$sizeof.pointer != 4){
     # checks ------------------------------------------------------------------
     mean(effect)
     
-    plot(subjpars[,1],baseline)
+    plot(subjpars[,'cint'],baseline)
     abline(0,1)
-    plot(subjpars[,2],effect)
+    plot(subjpars[,'diffusion'],effect)
     abline(0,1)
-    plot(subjpars[,3],t0m)
+    plot(subjpars[,'t0m'],t0m)
     abline(0,1)
     
-    plot(subjpars[,c(1,2)])
+    plot(subjpars[,c('diffusion','cint')])
     
     f$stanfit$transformedparsfull$popsd
     log1p_exp(2*f$stanfit$transformedparsfull$rawpopsdbase-1)
@@ -460,25 +460,25 @@ if(identical(Sys.getenv("NOT_CRAN"), "true")& .Machine$sizeof.pointer != 4){
     
     
     #sd checks
-    dfsd=data.frame(trueSample=c(sd(baseline),sd(t0m),sd(raweffect)),  #sample sd
+    dfsd=data.frame(trueSample=c(sd(t0m),sd(raweffect),sd(baseline)),  #sample sd
       # subjPars=sqrt(diag(cov(subjpars)))[c(2,3,1)], #sd of individual effect point estimates
-      f2est=sqrt(diag(f2$stanfit$transformedparsfull$pop_T0cov[1,,]))[c(3,1,2)],
-      f1est=f$stanfit$transformedparsfull$rawpopsd[,c(3,1,2)]) #population estimate
+      f2est=sqrt(diag(f2$stanfit$transformedparsfull$pop_T0cov[1,,])),
+      f1est=c(f$stanfit$transformedparsfull$rawpopsd)) #population estimate
     
-    dfsdtf=data.frame(trueSample=c(sd(baseline),sd(t0m),sd(effect)),  #sample sd
-      subjPars=sqrt(diag(cov(subjpars)))[c(1,3,2)], #sd of individual effect point estimates
-      s$popsd[c(3,1,2),]) #population estimate
+    dfsdtf=data.frame(trueSample=c(sd(t0m),sd(effect),sd(baseline)),  #sample sd
+      subjPars=sqrt(diag(cov(subjpars))), #sd of individual effect point estimates
+      s$popsd) #population estimate
     
     #test sd of ctsem between subjects setup vs manual specification
     testthat::expect_equivalent(sqrt(diag(f2$stanfit$transformedparsfull$pop_T0cov[1,,])),
-      f$stanfit$transformedparsfull$rawpopsd,tol=.01)
+      f$stanfit$transformedparsfull$rawpopsd,tol=.05)
     
     #test sd of ctsem between subjects setup vs subject specific pars
     testthat::expect_equivalent(dfsdtf$X50.,dfsdtf$subjPars,tol=.1)
     
     #test sd of ctsem between subjects setup vs true sample sd 
-    testthat::expect_equivalent(dfsd[,'trueSample'],dfsd[,'f1est'],tol=1e-1)
-    testthat::expect_equivalent(dfsdtf$X50.,dfsdtf[,'trueSample'],tol=.1)
+    testthat::expect_equivalent(dfsd[,'trueSample'],dfsd[,'f1est'],tol=.1)
+    testthat::expect_equivalent(dfsdtf$X50.,dfsdtf[,'trueSample'],tol=.1) 
     
     plot(density(sqrt(f2$stanfit$transformedpars$pop_T0cov[,2,2])),type='l') #distribution of pop sd estimates
     points(density(f$stanfit$transformedpars$rawpopsd[,2]),col=2,type='l') #distribution of pop sd estimates
@@ -505,7 +505,140 @@ if(identical(Sys.getenv("NOT_CRAN"), "true")& .Machine$sizeof.pointer != 4){
     
     #test corr of ctsem between subjects setup vs true sample sd -- why is t0means sd overestimated?
     testthat::expect_equivalent(dfcorr[,'trueSample'],
-      dfcorr[,'X50.'],tol=.1)
+      dfcorr[,'X50.'],tol=.2)
+    
+    
+  })
+  
+  test_that("randomEffectsMANIFESTVAR", {
+    set.seed(1)
+    nsubjects <- 400
+    ntimes <- 50
+    
+    baseline <- rnorm(nsubjects,2, 2)
+    t0m <- rnorm(nsubjects,baseline/2,1)
+    raweffect <- rnorm(nsubjects,-baseline/5, .3)
+    effect <- log1p(exp(raweffect))
+    
+    for(i in 1:nsubjects){
+      gm <- ctModel(Tpoints=ntimes,
+        LAMBDA=matrix(1), 
+        DRIFT= -1,
+        T0MEANS = c(t0m[i]),
+        MANIFESTVAR=effect[i],
+        DIFFUSION = 0.5,
+        T0VAR = c(0),
+        CINT = baseline[i],
+        MANIFESTMEANS=0)
+      
+      d <- data.frame(ctGenerate(ctmodelobj = gm,n.subjects = 1,burnin = 0,dtmean = .1,logdtsd = 0))
+      d$id <- i
+      if(i==1) dat <- d else dat <- rbind(dat,d)
+    }
+    
+    #regular bw effect approach
+    m <- ctModel(type='stanct',
+      T0MEANS='t0m|param',
+      DIFFUSION=.5,
+      MANIFESTMEANS=0,CINT='cint|param',
+      LAMBDA=matrix(1),MANIFESTVAR='errsd|log1p_exp(param)|TRUE')
+    
+    #manual bw effects
+    m2 <- ctModel(type='omx',Tpoints=3,
+      LAMBDA=matrix(c(1,0,0),ncol=3), 
+      DRIFT= c('drift',0,0,
+        0,-1e-12,0,
+        0,0,-1e-12),
+      DIFFUSION=c(.5,0,0,
+        0,0,0,
+        0,0,0),
+      MANIFESTVAR='log1p_exp(state[2])',
+      T0MEANS = c('t0m|param','errsd|param','cint|param'),
+      CINT=c('state[3]',0,0),
+      MANIFESTMEANS=0)
+    m2$T0VAR[diag(3)==1] <- paste0(m2$T0VAR[diag(3)==1] ,'|log1p_exp(2*param-1)')
+    m2=ctStanModel(m2,type='stanct')
+    m2$pars$indvarying=F
+    
+    f <- ctStanFit(datalong = dat,ctstanmodel = m,cores=cores,
+      optimcontrol = list(stochastic=F,carefulfit=F))#,init=f$stanfit$rawest)
+    s=summary(f)
+    s
+    subjpars=ctStanSubjectPars(f)[1,,c('t0m','errsd','cint')] #calculate subject specific parameter estimates
+    
+    f2 <- ctStanFit(datalong = dat,ctstanmodel = m2,cores=cores,optimcontrol = list(stochastic=F,carefulfit=F))
+    s2=summary(f2)
+    s2
+    cp2=ctStanContinuousPars(f2)
+    
+    
+    
+    # checks ------------------------------------------------------------------
+    mean(effect)
+    
+    plot(subjpars[,'cint'],baseline)
+    abline(0,1)
+    plot(subjpars[,'errsd'],effect)
+    abline(0,1)
+    plot(subjpars[,'t0m'],t0m)
+    abline(0,1)
+    
+    plot(subjpars[,c('errsd','cint')])
+    
+    f$stanfit$transformedparsfull$popsd
+    log1p_exp(2*f$stanfit$transformedparsfull$rawpopsdbase-1)
+    
+    #loglik checks
+    testthat::expect_equivalent(s$loglik,s2$loglik,tol=1e-2)
+    
+    
+    #sd checks
+    dfsd=data.frame(trueSample=c(sd(t0m),sd(raweffect),sd(baseline)),  #sample sd
+      # subjPars=sqrt(diag(cov(subjpars)))[c(2,3,1)], #sd of individual effect point estimates
+      f2est=sqrt(diag(f2$stanfit$transformedparsfull$pop_T0cov[1,,])),
+      f1est=c(f$stanfit$transformedparsfull$rawpopsd)) #population estimate
+    
+    dfsdtf=data.frame(trueSample=c(sd(t0m),sd(effect),sd(baseline)),  #sample sd
+      subjPars=sqrt(diag(cov(subjpars))), #sd of individual effect point estimates
+      s$popsd) #population estimate
+    
+    #test sd of ctsem between subjects setup vs manual specification
+    testthat::expect_equivalent(sqrt(diag(f2$stanfit$transformedparsfull$pop_T0cov[1,,])),
+      f$stanfit$transformedparsfull$rawpopsd,tol=.1)
+    
+    #test sd of ctsem between subjects setup vs subject specific pars
+    testthat::expect_equivalent(dfsdtf$X50.,dfsdtf$subjPars,tol=.1)
+    
+    #test sd of ctsem between subjects setup vs true sample sd 
+    testthat::expect_equivalent(dfsd[,'trueSample'],dfsd[,'f1est'],tol=.1)
+    testthat::expect_equivalent(dfsdtf$X50.,dfsdtf[,'trueSample'],tol=.1)
+    
+    plot(density(sqrt(f2$stanfit$transformedpars$pop_T0cov[,2,2])),type='l') #distribution of pop sd estimates
+    points(density(f$stanfit$transformedpars$rawpopsd[,2]),col=2,type='l') #distribution of pop sd estimates
+    
+    #cov checks
+    f$stanfit$transformedparsfull$popcov[1,,]
+    cov(subjpars)
+    cov(cbind(baseline,t0m,effect)) #true sample cov
+    
+    #rawcorr checks
+    dfcorr <- data.frame(trueSample=cor(cbind(t0m,raweffect,baseline))[lower.tri(diag(3))], #true sample cor,
+      # subjPars=cor(subjpars[,c(3,1,2)])[lower.tri(diag(3))],
+      # f1popCovbased=cov2cor(f$stanfit$transformedparsfull$popcov[1,,])[lower.tri(diag(3))],
+      f2est=cov2cor(f2$stanfit$transformedparsfull$pop_T0cov[1,,])[lower.tri(diag(3))],
+      s$rawpopcorr  )
+    
+    
+    
+    #test corr of ctsem between subjects setup vs manual specification
+    testthat::expect_equivalent(dfcorr$f2est,dfcorr$X50.,tol=.1)
+    
+    # #test corr of ctsem between subjects setup vs subject specific pars
+    # testthat::expect_equivalent(dfcorr$mean,dfcorr$subjPars,tol=.2)
+    
+    #test corr of ctsem between subjects setup vs true sample sd 
+    testthat::expect_equivalent(dfcorr[,'trueSample'],
+      dfcorr[,'X50.'],tol=.2)
     
     
   })
